@@ -56,9 +56,9 @@ def run_pg(image, ready_timeout=30.0):
             ):
                 break
 
-            time.sleep(500)
+            time.sleep(0.5)
         else:
-            raise Exception("Failed to start postgres")
+            raise Exception(f"Failed to start postgres using {image} in {ready_timeout} seconds")
 
         yield PostgresCredentials(
             host=LOCALHOST,
